after method
After successful evaluation
Implementation
@override
Future<void> after(HookContext context) async {
// Note: This hook may not be called by all SDK implementations
// We handle everything in finally_() to ensure it runs
}
After successful evaluation
@override
Future<void> after(HookContext context) async {
// Note: This hook may not be called by all SDK implementations
// We handle everything in finally_() to ensure it runs
}