IntelliToggleEvent class

Event emitted by IntelliToggle provider

Contains information about provider lifecycle events, errors, and flag evaluations for monitoring and debugging purposes.

Constructors

IntelliToggleEvent.configurationChanged([List<String>? flagsChanged])
Create a configuration changed event
factory
IntelliToggleEvent.error(String message, [dynamic error])
Create an error event
factory
IntelliToggleEvent.flagEvaluated(String flagKey, dynamic value, String reason, {String? variant, Map<String, dynamic>? context})
Create a flag evaluated event
factory
IntelliToggleEvent.initializing()
Create an initializing event
factory
IntelliToggleEvent.ready()
Create a ready event
factory
IntelliToggleEvent.shutdown()
Create a shutdown event
factory

Properties

data Map<String, dynamic>?
Additional event data (context-specific)
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Optional message describing the event
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Timestamp when event was created
final
type IntelliToggleEventType
Type of event
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited