IntelliToggleEventEmitter class

Event emitter for IntelliToggle provider events

Manages event broadcasting to subscribers using Dart streams. Provides a broadcast stream that multiple listeners can subscribe to.

Constructors

IntelliToggleEventEmitter()

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<IntelliToggleEvent>
no setter

Methods

dispose() → void
emit(IntelliToggleEvent event) → void
listen(void onData(IntelliToggleEvent)) StreamSubscription<IntelliToggleEvent>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited