IntelliToggleEventType enum

Event types for IntelliToggle provider lifecycle

These events are emitted during various stages of provider operation, allowing applications to monitor and react to provider state changes.

Inheritance
Available extensions

Values

ready → const IntelliToggleEventType

Provider is ready and connected

error → const IntelliToggleEventType

An error occurred

configurationChanged → const IntelliToggleEventType

Configuration changed (flags updated)

flagEvaluated → const IntelliToggleEventType

A flag was evaluated

initializing → const IntelliToggleEventType

Provider is initializing

shutdown → const IntelliToggleEventType

Provider is shutting down

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IntelliToggleEventType>
A constant List of the values in this enum, in order of their declaration.