IntelliToggleProvider class
New IntelliToggle provider implementation with corrected API endpoints
- Implemented types
Constructors
- IntelliToggleProvider({required String clientId, required String clientSecret, required String tenantId, IntelliToggleOptions? options, Client? httpClient})
- Creates a new IntelliToggle provider instance with corrected endpoints
Properties
- config → ProviderConfig
-
no setteroverride
-
events
→ Stream<
IntelliToggleEvent> -
Get event stream for listening to provider lifecycle events
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
localFlags
→ Map<
String, dynamic> -
Get current local flags (for debugging)
no setter
- metadata → ProviderMetadata
-
no setteroverride
- name → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ProviderState
-
no setteroverride
Methods
-
connect(
) → Future< void> -
override
-
getBooleanFlag(
String flagKey, bool defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< bool> > -
override
-
getDoubleFlag(
String flagKey, double defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< double> > -
override
-
getIntegerFlag(
String flagKey, int defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< int> > -
override
-
getObjectFlag(
String flagKey, Map< String, dynamic> defaultValue, {Map<String, dynamic> ? context}) → Future<FlagEvaluationResult< Map< >String, dynamic> > -
override
-
getStringFlag(
String flagKey, String defaultValue, {Map< String, dynamic> ? context}) → Future<FlagEvaluationResult< String> > -
override
-
initialize(
[Map< String, dynamic> ? context]) → Future<void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shutdown(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
String trackingEventName, {Map< String, dynamic> ? evaluationContext, TrackingEventDetails? trackingDetails}) → Future<void> -
Tracking API (spec Section 6) - record a tracking event
Providers that do not support tracking should silently no-op.
override
-
updateLocalFlags(
Map< String, dynamic> newFlags) → void - Manually update local flags (for testing or manual refresh)
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited