IntelliToggleUtils class

HTTP utilities and helper functions for IntelliToggle API communication

Constructors

IntelliToggleUtils(Client _httpClient, IntelliToggleOptions _options, {required String clientId, required String clientSecret, required String tenantId})

Properties

clientId String
final
clientSecret String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String
final

Methods

buildHeaders() Future<Map<String, String>>
Build headers with OAuth2 token
evaluateFlag(String flagKey, Map<String, dynamic> context, String valueType) Future<Map<String, dynamic>>
Evaluate a flag via IntelliToggle API
evaluateFlagOfrep(String flagKey, Map<String, dynamic> context, String valueType, dynamic defaultValue) Future<Map<String, dynamic>>
Evaluate a flag via OFREP (Appendix C) endpoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited