IntelliToggleContextProcessor class
Context processing and validation for IntelliToggle evaluations.
Handles single-context, multi-context, and custom context kinds with proper validation and transformation for the IntelliToggle API.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onContextChanged(
Map< String, dynamic> newContext) → void - Called when the evaluation context changes (per spec)
-
processContext(
Map< String, dynamic> ? context) → Map<String, dynamic> - Process evaluation context for IntelliToggle API
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited